@@ -362,13 +362,14 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
     private Media mMedia = null;
     private boolean mPlaying = false;
     private boolean mPlayRequested = false;
-    private boolean mAudioDeviceFromUser = false;
+    private boolean mListenAudioPlug = true;
     private int mVoutCount = 0;
     private boolean mAudioReset = false;
     private String mAudioOutput = "android_audiotrack";
     private String mAudioOutputDevice = null;
 
     private boolean mAudioPlugRegistered = false;
+    private boolean mAudioDigitalOutputEnabled = false;
     private String mAudioPlugOutputDevice = "stereo";
 
     private final AWindow mWindow = new AWindow(new AWindow.SurfaceCallback() {
@@ -400,8 +401,8 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
         }
     });
 
-    private void updateAudioOutputDevice(long encodingFlags, String defaultDevice) {
-        final String newDeviceId = encodingFlags != 0 ? "encoded:" + encodingFlags : defaultDevice;
+    private synchronized void updateAudioOutputDevice(long encodingFlags, String defaultDevice) {
+        final String newDeviceId = mAudioDigitalOutputEnabled && encodingFlags != 0 ? "encoded:" + encodingFlags : defaultDevice;
         if (!newDeviceId.equals(mAudioPlugOutputDevice)) {
             mAudioPlugOutputDevice = newDeviceId;
             setAudioOutputDeviceInternal(mAudioPlugOutputDevice, false);
@@ -615,7 +616,7 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
                         nativeSetAudioOutputDevice(mAudioOutputDevice);
                     mAudioReset = false;
                 }
-                if (!mAudioDeviceFromUser)
+                if (mListenAudioPlug)
                     registerAudioPlug(true);
                 mPlayRequested = true;
                 if (mWindow.areSurfacesWaiting())
@@ -690,6 +691,10 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
         nativeSetAspectRatio(aspect);
     }
 
+    private boolean isAudioTrack() {
+        return mAudioOutput != null && mAudioOutput.equals("android_audiotrack");
+    }
+
     /**
      * Update the video viewpoint information
      *
@@ -717,50 +722,108 @@ public class MediaPlayer extends VLCObject<MediaPlayer.Event> {
      *
      * @return true on success.
      */
-    public boolean setAudioOutput(String aout) {
+    public synchronized boolean setAudioOutput(String aout) {
+        mAudioOutput = aout;
+        /* If The user forced an output different than AudioTrack, don't listen to audio
+         * plug events and let the user decide */
+        mListenAudioPlug = isAudioTrack();
+        if (!mListenAudioPlug)
+            registerAudioPlug(false);
+
         final boolean ret = nativeSetAudioOutput(aout);
-        if (ret) {
-            synchronized (this) {
-                mAudioOutput = aout;
-                /* The user forced an output, don't listen to audio plug events and let the user decide */
-                mAudioDeviceFromUser = true;
+
+        if (!ret) {
+            mAudioOutput = null;
+            mListenAudioPlug = false;
+        }
+
+        if (mListenAudioPlug)
+            registerAudioPlug(true);
+
+        return ret;
+    }
+
+    /**
+     * Enable or disable Digital Output
+     *
+     * Works only with AudioTrack AudioOutput.
+     * If {@link #setAudioOutputDevice} was previously called, this method won't have any effects.
+     *
+     * @param enabled true to enable Digital Output
+     * @return true on success
+     */
+    public synchronized boolean setAudioDigitalOutputEnabled(boolean enabled) {
+        if (enabled == mAudioDigitalOutputEnabled)
+            return true;
+        if (!mListenAudioPlug || !isAudioTrack())
+            return false;
+
+        registerAudioPlug(false);
+        mAudioDigitalOutputEnabled = enabled;
+        registerAudioPlug(true);
+        return true;
+    }
+
+    /** Convenient method for {@link #setAudioOutputDevice}
+     *
+     * @param encodings list of encodings to play via passthrough (see AudioFormat.ENCODING_*),
+     *                  null to don't force any.
+     * @return true on success
+     */
+    public synchronized boolean forceAudioDigitalEncodings(int []encodings) {
+        if (!isAudioTrack())
+            return false;
+
+        if (encodings.length == 0)
+            setAudioOutputDeviceInternal(null, true);
+        else {
+            final String newDeviceId = "encoded:" + getEncodingFlags(encodings);
+            if (!newDeviceId.equals(mAudioPlugOutputDevice)) {
+                mAudioPlugOutputDevice = newDeviceId;
+                setAudioOutputDeviceInternal(mAudioPlugOutputDevice, true);
+            }
+        }
+        return true;
+    }
+
+    private synchronized boolean setAudioOutputDeviceInternal(String id, boolean fromUser) {
+        mAudioOutputDevice = id;
+        if (fromUser) {
+            /* The user forced a device, don't listen to audio plug events and let the user decide */
+            mListenAudioPlug = mAudioOutputDevice == null && isAudioTrack();
+            if (!mListenAudioPlug)
                 registerAudioPlug(false);
-            }
         }
-        return ret;
-    }
 
-    private boolean setAudioOutputDeviceInternal(String id, boolean fromUser) {
         final boolean ret = nativeSetAudioOutputDevice(id);
-        if (ret) {
-            synchronized (this) {
-                mAudioOutputDevice = id;
-                if (fromUser) {
-                    /* The user forced a device, don't listen to audio plug events and let the user decide */
-                    mAudioDeviceFromUser = true;
-                    registerAudioPlug(false);
-                }
-            }
+
+        if (!ret) {
+            mAudioOutputDevice = null;
+            mListenAudioPlug = false;
         }
+
+        if (mListenAudioPlug)
+            registerAudioPlug(true);
+
         return ret;
     }
 
-        /**
-         * Configures an explicit audio output device.
-         * Audio output will be moved to the device specified by the device identifier string.
-         *
-         * Available devices for the "android_audiotrack" module (the default) are
-         * "stereo": Up to 2 channels (compat mode).
-         * "pcm": Up to 8 channels.
-         * "encoded": Up to 8 channels, passthrough for every encodings if available.
-         * "encoded:ENCODING_FLAGS_MASK": passthrough for every encodings specified by
-         * ENCODING_FLAGS_MASK. This extra value is a long that contains binary-shifted
-         * AudioFormat.ENCODING_* values.
-         *
-         * Calling this method will disable the encoding detection (see {@link #setAudioOutput}).
-         *
-         * @return true on success.
-         */
+    /**
+     * Configures an explicit audio output device.
+     * Audio output will be moved to the device specified by the device identifier string.
+     *
+     * Available devices for the "android_audiotrack" module (the default) are
+     * "stereo": Up to 2 channels (compat mode).
+     * "pcm": Up to 8 channels.
+     * "encoded": Up to 8 channels, passthrough for every encodings if available.
+     * "encoded:ENCODING_FLAGS_MASK": passthrough for every encodings specified by
+     * ENCODING_FLAGS_MASK. This extra value is a long that contains binary-shifted
+     * AudioFormat.ENCODING_* values.
+     *
+     * Calling this method will disable the encoding detection (see {@link #setAudioOutput} and {@link #setAudioDigitalOutputEnabled(boolean)}).
+     *
+     * @return true on success.
+     */
     public boolean setAudioOutputDevice(String id) {
         return setAudioOutputDeviceInternal(id, true);
     }
