@@ -21,6 +21,7 @@
 package org.videolan.vlc;
 
 import android.annotation.TargetApi;
+import android.app.Activity;
 import android.app.KeyguardManager;
 import android.app.Notification;
 import android.app.PendingIntent;
@@ -114,8 +115,8 @@ public class PlaybackService extends MediaBrowserServiceCompat{
     private static final int SHOW_TOAST = 1;
     private static final int END_MEDIASESSION = 2;
 
-    private static final int DELAY_DOUBLE_CLICK = 800;
-    private static final int DELAY_LONG_CLICK = 1000;
+    private static final long DELAY_DOUBLE_CLICK = 800L;
+    private static final long DELAY_LONG_CLICK = 1000L;
 
     public interface Callback {
         void update();
@@ -802,8 +803,8 @@ public class PlaybackService extends MediaBrowserServiceCompat{
     }
 
     private final class MediaSessionCallback extends MediaSessionCompat.Callback {
-        private long mHeadsetDownTime = 0;
-        private long mHeadsetUpTime = 0;
+        private long mHeadsetDownTime = 0L;
+        private long mHeadsetUpTime = 0L;
 
         @Override
         public boolean onMediaButtonEvent(Intent mediaButtonEvent) {
@@ -816,8 +817,7 @@ public class PlaybackService extends MediaBrowserServiceCompat{
                     final long time = SystemClock.uptimeMillis();
                     switch (event.getAction()) {
                         case KeyEvent.ACTION_DOWN:
-                            if (event.getRepeatCount() <= 0)
-                                mHeadsetDownTime = time;
+                            if (event.getRepeatCount() <= 0) mHeadsetDownTime = time;
                             if (!hasMedia()) {
                                 loadLastAudioPlaylist();
                                 return true;
@@ -1725,6 +1725,16 @@ public class PlaybackService extends MediaBrowserServiceCompat{
         return playlistManager.getPlayer().setAudioTrack(index);
     }
 
+    @MainThread
+    public boolean setAudioDigitalOutputEnabled(boolean enabled) {
+        return playlistManager.getPlayer().setAudioDigitalOutputEnabled(enabled);
+    }
+
+    @MainThread
+    public boolean setVideoTrack(int index) {
+        return playlistManager.getPlayer().setVideoTrack(index);
+    }
+
     @MainThread
     public int getVideoTracksCount() {
         return hasMedia() ? playlistManager.getPlayer().getVideoTracksCount() : 0;
@@ -1878,7 +1888,8 @@ public class PlaybackService extends MediaBrowserServiceCompat{
         public void connect() {
             if (mBound) throw new IllegalStateException("already connected");
             final Intent serviceIntent = getServiceIntent(mContext);
-            Util.startService(mContext, serviceIntent);
+            if (mContext instanceof Activity) mContext.startService(serviceIntent);
+            else Util.startService(mContext, serviceIntent);
             mBound = mContext.bindService(serviceIntent, mServiceConnection, BIND_AUTO_CREATE);
         }
 
