@@ -113,7 +113,6 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
     private void initAudioPlayer() {
         ((ViewStubCompat)findViewById(R.id.audio_player_stub)).inflate();
         mAudioPlayer = (AudioPlayer) getSupportFragmentManager().findFragmentById(R.id.audio_player);
-        mAudioPlayer.setUserVisibleHint(false);
         mBottomSheetBehavior = BottomSheetBehavior.from(mAudioPlayerContainer);
         mBottomSheetBehavior.setPeekHeight(getResources().getDimensionPixelSize(R.dimen.player_peek_height));
         mBottomSheetBehavior.setBottomSheetCallback(mAudioPlayerBottomSheetCallback);
@@ -313,13 +312,12 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
 
     private void updateProgressVisibility(int visibility) {
         boolean show = visibility == View.VISIBLE;
-        if ((mScanProgressLayout == null && !show) ||
-                (mScanProgressLayout != null && mScanProgressLayout.getVisibility() == visibility))
-            return;
-        if (show)
-            mActivityHandler.sendEmptyMessageDelayed(ACTION_DISPLAY_PROGRESSBAR, 1000);
-        else if (mScanProgressLayout != null)
-            mScanProgressLayout.setVisibility(visibility);
+        if (mScanProgressLayout != null && mScanProgressLayout.getVisibility() == visibility) return;
+        if (show) mActivityHandler.sendEmptyMessageDelayed(ACTION_DISPLAY_PROGRESSBAR, 1000);
+        else {
+            mActivityHandler.removeMessages(ACTION_DISPLAY_PROGRESSBAR);
+            UiTools.setViewVisibility(mScanProgressLayout, visibility);
+        }
     }
 
     private void showProgressBar() {
@@ -333,8 +331,7 @@ public class AudioPlayerContainerActivity extends BaseActivity implements Playba
                 updateContainerPadding(true);
                 applyMarginToProgressBar(mBottomSheetBehavior.getPeekHeight());
             }
-        } else if (mScanProgressLayout != null)
-            mScanProgressLayout.setVisibility(View.VISIBLE);
+        } else if (mScanProgressLayout != null) mScanProgressLayout.setVisibility(View.VISIBLE);
     }
 
     private void updateContainerPadding(boolean show) {
